@@ -6,11 +6,16 @@ from textwrap import TextWrapper
 from collections import defaultdict
 
 from plumbum.lib import six, getdoc
-from plumbum.cli.terminal import get_terminal_size
-from plumbum.cli.switches import (SwitchError, UnknownSwitch, MissingArgument, WrongArgumentType,
+from .terminal import get_terminal_size
+from .switches import (SwitchError, UnknownSwitch, MissingArgument, WrongArgumentType,
     MissingMandatorySwitch, SwitchCombinationError, PositionalArgumentsError, switch,
     SubcommandError, Flag, CountOf)
+
 from plumbum import colors, local
+from plumbum.cli.i18n import get_translation_for
+
+_translation = get_translation_for(__name__)
+T_, ngettext = _translation.gettext, _translation.ngettext
 
 
 class ShowHelp(SwitchError):
@@ -38,14 +43,15 @@ class Subcommand(object):
             try:
                 cls = getattr(mod, clsname)
             except AttributeError:
-                raise ImportError("cannot import name %s" % (clsname,))
+                raise ImportError("cannot import name {0}".format(clsname))
             self.subapplication = cls
         return self.subapplication
 
     def __repr__(self):
-        return "Subcommand(%r, %r)" % (self.name, self.subapplication)
-
+        return T_("Subcommand({self.name}, {self.subapplication})").format(self=self)
 
+_switch_groups = ['Switches', 'Meta-switches']
+_switch_groups_l10n = [T_('Switches'), T_('Meta-switches')]
 #===================================================================================================
 # CLI Application base class
 #===================================================================================================
@@ -114,7 +120,7 @@ class Application(object):
     COLOR_USAGE = None
     COLOR_GROUPS = None
     CALL_MAIN_IF_NESTED_COMMAND = True
-    SUBCOMMAND_HELPMSG = "see '{parent} {sub} --help' for more info"
+    SUBCOMMAND_HELPMSG = T_("see '{parent} {sub} --help' for more info")
 
     parent = None
     nested_command = None
@@ -145,9 +151,11 @@ class Application(object):
             self.DESCRIPTION = getdoc(self)
 
         # Allow None for the colors
-        self.COLOR_GROUPS=defaultdict(lambda:colors.do_nothing, dict() if type(self).COLOR_GROUPS is None else type(self).COLOR_GROUPS )
+        self.COLOR_GROUPS = defaultdict(
+            lambda:colors.do_nothing,
+            dict() if type(self).COLOR_GROUPS is None else type(self).COLOR_GROUPS)
         if type(self).COLOR_USAGE is None:
-            self.COLOR_USAGE=colors.do_nothing
+            self.COLOR_USAGE = colors.do_nothing
 
         self.executable = executable
         self._switches_by_name = {}
@@ -160,7 +168,7 @@ class Application(object):
                 if isinstance(obj, Subcommand):
                     name = colors.filter(obj.name)
                     if name.startswith("-"):
-                        raise SubcommandError("Subcommand names cannot start with '-'")
+                        raise SubcommandError(T_("Subcommand names cannot start with '-'"))
                     # it's okay for child classes to override subcommands set by their parents
                     self._subcommands[name] = obj
                     continue
@@ -172,7 +180,8 @@ class Application(object):
                     if name in self._unbound_switches:
                         continue
                     if name in self._switches_by_name and not self._switches_by_name[name].overridable:
-                        raise SwitchError("Switch %r already defined and is not overridable" % (name,))
+                        raise SwitchError(
+                            T_("Switch {name} already defined and is not overridable").format(name=name))
                     self._switches_by_name[name] = swinfo
                     self._switches_by_func[swinfo.func] = swinfo
                     if swinfo.envname:
@@ -219,7 +228,8 @@ class Application(object):
 
         """
         def wrapper(subapp):
-            attrname = "_subcommand_%s" % (subapp if isinstance(subapp, str) else subapp.__name__,)
+            attrname = "_subcommand_{0}".format(
+                subapp if isinstance(subapp, str) else subapp.__name__)
             setattr(cls, attrname, Subcommand(name, subapp))
             return subapp
         return wrapper(subapp) if subapp else wrapper
@@ -254,18 +264,18 @@ class Application(object):
                     name = a[2:]
                 swname = "--" + name
                 if name not in self._switches_by_name:
-                    raise UnknownSwitch("Unknown switch %s" % (swname,))
+                    raise UnknownSwitch(T_("Unknown switch {0}").format(swname))
                 swinfo = self._switches_by_name[name]
                 if swinfo.argtype:
                     if not argv:
-                        raise MissingArgument("Switch %s requires an argument" % (swname,))
+                        raise MissingArgument(T_("Switch {0} requires an argument").format(swname))
                     a = argv.pop(0)
                     if a and a[0] == "=":
                         if len(a) >= 2:
                             val = a[1:]
                         else:
                             if not argv:
-                                raise MissingArgument("Switch %s requires an argument" % (swname))
+                                raise MissingArgument(T_("Switch {0} requires an argument").format(swname))
                             val = argv.pop(0)
                     else:
                         val = a
@@ -275,21 +285,21 @@ class Application(object):
                 name = a[1]
                 swname = "-" + name
                 if name not in self._switches_by_name:
-                    raise UnknownSwitch("Unknown switch %s" % (swname,))
+                    raise UnknownSwitch(T_("Unknown switch {0}").format(swname))
                 swinfo = self._switches_by_name[name]
                 if swinfo.argtype:
                     if len(a) >= 3:
                         val = a[2:]
                     else:
                         if not argv:
-                            raise MissingArgument("Switch %s requires an argument" % (swname,))
+                            raise MissingArgument(T_("Switch {0} requires an argument").format(swname))
                         val = argv.pop(0)
                 elif len(a) >= 3:
                     argv.insert(0, "-" + a[2:])
 
             else:
                 if a.startswith("-"):
-                    raise UnknownSwitch("Unknown switch %s" % (a,))
+                    raise UnknownSwitch(T_("Unknown switch {0}").format(a))
                 tailargs.append(a)
                 continue
 
@@ -301,10 +311,11 @@ class Application(object):
                     swfuncs[swinfo.func].val[0].append(val)
                 else:
                     if swfuncs[swinfo.func].swname == swname:
-                        raise SwitchError("Switch %r already given" % (swname,))
+                        raise SwitchError(T_("Switch {0} already given").format(swname))
                     else:
-                        raise SwitchError("Switch %r already given (%r is equivalent)" % (
-                            swfuncs[swinfo.func].swname, swname))
+                        raise SwitchError(
+                            T_("Switch {0} already given ({1} is equivalent)").format(
+                                swfuncs[swinfo.func].swname, swname))
             else:
                 if swinfo.list:
                     swfuncs[swinfo.func] = SwitchParseInfo(swname, ([val],), index)
@@ -325,7 +336,7 @@ class Application(object):
                 continue  # skip if overridden by command line arguments
 
             val = self._handle_argument(envval, swinfo.argtype, env)
-            envname = "$%s" % (env,)
+            envname = "${0}".format(env)
             if swinfo.list:
                 # multiple values over environment variables are not supported,
                 # this will require some sort of escaping and separator convention
@@ -349,8 +360,8 @@ class Application(object):
                 return argtype(val)
             except (TypeError, ValueError):
                 ex = sys.exc_info()[1]  # compat
-                raise WrongArgumentType("Argument of %s expected to be %r, not %r:\n    %r" % (
-                    name, argtype, val, ex))
+                raise WrongArgumentType(T_("Argument of {name} expected to be {argtype}, not {val!r}:\n    {ex!r}").format(
+                    name=name, argtype=argtype, val=val, ex=ex))
         else:
             return NotImplemented
 
@@ -366,8 +377,8 @@ class Application(object):
         exclusions = {}
         for swinfo in self._switches_by_func.values():
             if swinfo.mandatory and not swinfo.func in swfuncs:
-                raise MissingMandatorySwitch("Switch %s is mandatory" %
-                    ("/".join(("-" if len(n) == 1 else "--") + n for n in swinfo.names),))
+                raise MissingMandatorySwitch(T_("Switch {0} is mandatory").format(
+                    "/".join(("-" if len(n) == 1 else "--") + n for n in swinfo.names)))
             requirements[swinfo.func] = set(self._switches_by_name[req] for req in swinfo.requires)
             exclusions[swinfo.func] = set(self._switches_by_name[exc] for exc in swinfo.excludes)
 
@@ -377,22 +388,33 @@ class Application(object):
         for func in gotten:
             missing = set(f.func for f in requirements[func]) - gotten
             if missing:
-                raise SwitchCombinationError("Given %s, the following are missing %r" %
-                    (swfuncs[func].swname, [self._switches_by_func[f].names[0] for f in missing]))
+                raise SwitchCombinationError(
+                    T_("Given {0}, the following are missing {1}").format(
+                        swfuncs[func].swname,
+                        [self._switches_by_func[f].names[0] for f in missing]))
             invalid = set(f.func for f in exclusions[func]) & gotten
             if invalid:
-                raise SwitchCombinationError("Given %s, the following are invalid %r" %
-                    (swfuncs[func].swname, [swfuncs[f].swname for f in invalid]))
+                raise SwitchCombinationError(
+                    T_("Given {0}, the following are invalid {1}").format(
+                        swfuncs[func].swname, [swfuncs[f].swname for f in invalid]))
 
         m = six.getfullargspec(self.main)
         max_args = six.MAXSIZE if m.varargs else len(m.args) - 1
         min_args = len(m.args) - 1 - (len(m.defaults) if m.defaults else 0)
         if len(tailargs) < min_args:
-            raise PositionalArgumentsError("Expected at least %d positional arguments, got %r" %
-                (min_args, tailargs))
+            raise PositionalArgumentsError(
+                ngettext(
+                    "Expected at least {0} positional argument, got {1}",
+                    "Expected at least {0} positional arguments, got {1}",
+                    min_args).format(
+                        min_args, tailargs))
         elif len(tailargs) > max_args:
-            raise PositionalArgumentsError("Expected at most %d positional arguments, got %r" %
-                (max_args, tailargs))
+            raise PositionalArgumentsError(
+                ngettext(
+                    "Expected at most {0} positional argument, got {1}",
+                    "Expected at most {0} positional arguments, got {1}",
+                    max_args).format(
+                        max_args, tailargs))
 
         # Positional arguement validataion
         if hasattr(self.main, 'positional'):
@@ -408,7 +430,7 @@ class Application(object):
             for item in m.annotations:
                 if item == m.varargs:
                     varargs = m.annotations[item]
-                else:
+                elif item != 'return':
                     positional[args_names.index(item)] = m.annotations[item]
 
             tailargs = self._positional_validate(tailargs, positional, varargs,
@@ -467,8 +489,8 @@ class Application(object):
             inst.version()
         except SwitchError:
             ex = sys.exc_info()[1]  # compatibility with python 2.5
-            print("Error: %s" % (ex,))
-            print("------")
+            print(T_("Error: {0}").format(ex))
+            print(T_("------"))
             inst.help()
             retcode = 2
         else:
@@ -536,11 +558,11 @@ class Application(object):
             if isinstance(switch, CountOf):
                 p = (range(val),)
             elif swinfo.list and not hasattr(val, "__iter__"):
-                raise SwitchError("Switch %r must be a sequence (iterable)" % (swname,))
+                raise SwitchError(T_("Switch {0} must be a sequence (iterable)").format(swname))
             elif not swinfo.argtype:
                 # a flag
                 if val not in (True, False, None, Flag):
-                    raise SwitchError("Switch %r is a boolean flag" % (swname,))
+                    raise SwitchError(T_("Switch {0} is a boolean flag").format(swname))
                 p = ()
             else:
                 p = (val,)
@@ -551,17 +573,17 @@ class Application(object):
         """Implement me (no need to call super)"""
         if self._subcommands:
             if args:
-                print("Unknown sub-command %r" % (args[0],))
-                print("------")
+                print(T_("Unknown sub-command '{0}'").format(args[0]))
+                print(T_("------"))
                 self.help()
                 return 1
             if not self.nested_command:
-                print("No sub-command given")
-                print("------")
+                print(T_("No sub-command given"))
+                print(T_("------"))
                 self.help()
                 return 1
         else:
-            print("main() not implemented")
+            print(T_("main() not implemented"))
             return 1
 
     def cleanup(self, retcode):
@@ -570,7 +592,9 @@ class Application(object):
         :param retcode: the return code of ``main()``
         """
 
-    @switch(["--help-all"], overridable = True, group = "Meta-switches")
+    @switch(
+        ["--help-all"], overridable = True, group = "Meta-switches",
+        help=T_("""Print help messages of all subcommands and quit"""))
     def helpall(self):
         """Print help messages of all subcommands and quit"""
         self.help()
@@ -578,14 +602,16 @@ class Application(object):
 
         if self._subcommands:
             for name, subcls in sorted(self._subcommands.items()):
-                subapp = (subcls.get())("%s %s" % (self.PROGNAME, name))
+                subapp = (subcls.get())("{0} {1}".format(self.PROGNAME, name))
                 subapp.parent = self
                 for si in subapp._switches_by_func.values():
                     if si.group == "Meta-switches":
                         si.group = "Hidden-switches"
                 subapp.helpall()
 
-    @switch(["-h", "--help"], overridable = True, group = "Meta-switches")
+    @switch(
+        ["-h", "--help"], overridable = True, group = "Meta-switches",
+        help=T_("""Prints this help message and quits"""))
     def help(self):  # @ReservedAssignment
         """Prints this help message and quits"""
         if self._get_prog_version():
@@ -598,19 +624,19 @@ class Application(object):
         tailargs = m.args[1:]  # skip self
         if m.defaults:
             for i, d in enumerate(reversed(m.defaults)):
-                tailargs[-i - 1] = "[%s=%r]" % (tailargs[-i - 1], d)
+                tailargs[-i - 1] = "[{0}={1}]".format(tailargs[-i - 1], d)
         if m.varargs:
-            tailargs.append("%s..." % (m.varargs,))
+            tailargs.append("{0}...".format(m.varargs,))
         tailargs = " ".join(tailargs)
 
         with self.COLOR_USAGE:
-            print("Usage:")
+            print(T_("Usage:"))
             if not self.USAGE:
                 if self._subcommands:
-                    self.USAGE = "    %(progname)s [SWITCHES] [SUBCOMMAND [SWITCHES]] %(tailargs)s\n"
+                    self.USAGE = T_("    {progname} [SWITCHES] [SUBCOMMAND [SWITCHES]] {tailargs}\n")
                 else:
-                    self.USAGE = "    %(progname)s [SWITCHES] %(tailargs)s\n"
-            print(self.USAGE % {"progname": colors.filter(self.PROGNAME), "tailargs": tailargs})
+                    self.USAGE = T_("    {progname} [SWITCHES] {tailargs}\n")
+            print(self.USAGE.format(progname=colors.filter(self.PROGNAME), tailargs=tailargs))
 
         by_groups = {}
         for si in self._switches_by_func.values():
@@ -621,17 +647,18 @@ class Application(object):
         def switchs(by_groups, show_groups):
             for grp, swinfos in sorted(by_groups.items(), key = lambda item: item[0]):
                 if show_groups:
-                    print(self.COLOR_GROUPS[grp] | grp)
+                    lgrp = T_(grp) if grp in _switch_groups else grp
+                    print(self.COLOR_GROUPS[grp] | lgrp + ':')
 
                 for si in sorted(swinfos, key = lambda si: si.names):
                     swnames = ", ".join(("-" if len(n) == 1 else "--") + n for n in si.names
                         if n in self._switches_by_name and self._switches_by_name[n] == si)
                     if si.argtype:
-                        if isinstance(si.argtype, type):
+                        if hasattr(si.argtype, '__name__'):
                             typename = si.argtype.__name__
                         else:
                             typename = str(si.argtype)
-                        argtype = " %s:%s" % (si.argname.upper(), typename)
+                        argtype = " {0}:{1}".format(si.argname.upper(), typename)
                     else:
                         argtype = ""
                     prefix = swnames + argtype
@@ -642,20 +669,26 @@ class Application(object):
 
         sw_width = max(len(prefix) for si, prefix, color in switchs(by_groups, False)) + 4
         cols, _ = get_terminal_size()
-        description_indent = "    %s%s%s"
+        description_indent = "    {0}{1}{2}"
         wrapper = TextWrapper(width = max(cols - min(sw_width, 60), 50) - 6)
         indentation = "\n" + " " * (cols - wrapper.width)
 
-        for si, prefix, color in switchs(by_groups, True):
-            help = si.help  # @ReservedAssignment
-            if si.list:
-                help += "; may be given multiple times"
-            if si.mandatory:
-                help += "; required"
-            if si.requires:
-                help += "; requires %s" % (", ".join((("-" if len(s) == 1 else "--") + s) for s in si.requires))
-            if si.excludes:
-                help += "; excludes %s" % (", ".join((("-" if len(s) == 1 else "--") + s) for s in si.excludes))
+        for switch_info, prefix, color in switchs(by_groups, True):
+            help = switch_info.help  # @ReservedAssignment
+            if switch_info.list:
+                help += T_("; may be given multiple times")
+            if switch_info.mandatory:
+                help += T_("; required")
+            if switch_info.requires:
+                help += T_("; requires {0}").format(
+                    ", ".join(
+                        (("-" if len(switch) == 1 else "--") + switch)
+                        for switch in switch_info.requires))
+            if switch_info.excludes:
+                help += T_("; excludes {0}").format(
+                    ", ".join(
+                        (("-" if len(switch) == 1 else "--") + switch)
+                        for switch in switch_info.excludes))
 
             msg = indentation.join(wrapper.wrap(" ".join(l.strip() for l in help.splitlines())))
 
@@ -663,11 +696,11 @@ class Application(object):
                 padding = indentation
             else:
                 padding = " " * max(cols - wrapper.width - len(prefix) - 4, 1)
-            print(description_indent % (color | prefix, padding, color | msg))
+            print(description_indent.format(color | prefix, padding, color | msg))
 
         if self._subcommands:
             gc = self.COLOR_GROUPS["Subcommands"]
-            print(gc | "Subcommands:")
+            print(gc | T_("Subcommands:"))
             for name, subcls in sorted(self._subcommands.items()):
                 with gc:
                     subapp = subcls.get()
@@ -689,10 +722,9 @@ class Application(object):
                     else:
                         bodycolor = gc
 
-                    print(description_indent
-                            % (subcls.name, padding,
-                               bodycolor | colors.filter(msg)))
-
+                    print(description_indent.format(
+                        subcls.name, padding,
+                        bodycolor | colors.filter(msg)))
 
 
     def _get_prog_version(self):
@@ -705,10 +737,11 @@ class Application(object):
             curr = curr.parent
         return ver
 
-    @switch(["-v", "--version"], overridable = True, group = "Meta-switches")
+    @switch(
+        ["-v", "--version"], overridable = True, group = "Meta-switches",
+        help=T_("""Prints the program's version and quits"""))
     def version(self):
         """Prints the program's version and quits"""
         ver = self._get_prog_version()
-        ver_name = ver if ver is not None else "(version not set)"
+        ver_name = ver if ver is not None else T_("(version not set)")
         print('{0} {1}'.format(self.PROGNAME, ver_name))
-
