@@ -1,8 +1,8 @@
 from __future__ import print_function, division
 
 from plumbum import colors
-from plumbum.cli.termsize import get_terminal_size
-from plumbum import cli
+from .termsize import get_terminal_size
+from .. import cli
 import sys
 
 class Image(object):
@@ -23,14 +23,11 @@ class Image(object):
             return term
 
         orig_ratio = orig[0]/orig[1]/self.char_ratio
-        print(orig_ratio)
 
         if int(term[1]/orig_ratio) <= term[0]:
             new_size = int(term[1]/orig_ratio), term[1]
-            print("First", term, new_size)
         else:
             new_size = term[0], int(term[0]*orig_ratio)
-            print("Second", term, new_size)
         return new_size
 
     def show(self, filename, double=False):
@@ -53,7 +50,7 @@ class Image(object):
     def show_pil(self, im):
         'Standard show routine'
         size = self._init_size(im)
-        new_im = im.resize(size)
+        new_im = im.resize(size).convert("RGB")
 
         for y in range(size[1]):
             for x in range(size[0]-1):
@@ -67,13 +64,13 @@ class Image(object):
 
         size = self._init_size(im)
         size= (size[0], size[1]*2)
-        new_im = im.resize(size)
+        new_im = im.resize(size).convert("RGB")
 
         for y in range(size[1]//2):
             for x in range(size[0]-1):
                 pix = new_im.getpixel((x,y*2))
                 pixl = new_im.getpixel((x,y*2+1))
-                print(colors.bg.rgb(*pixl) & colors.fg.rgb(*pix), '\u2580', sep='', end='')
+                print(colors.bg.rgb(*pixl) & colors.fg.rgb(*pix), u'\u2580', sep='', end='')
             print(colors.reset, ' ', sep='')
         print(colors.reset)
 
