@@ -7,8 +7,8 @@ from __future__ import division, print_function, absolute_import
 import sys
 import os
 from plumbum import local
-from plumbum.cli.termsize import get_terminal_size
-from plumbum.cli.progress import Progress
+from .termsize import get_terminal_size
+from .progress import Progress
 
 def readline(message = ""):
     """Gets a line of input from the user (stdin)"""
@@ -108,7 +108,7 @@ def choose(question, options, default = None):
             continue
         return choices[choice]
 
-def prompt(question, type = int, default = NotImplemented, validator = lambda val: True):
+def prompt(question, type = str, default = NotImplemented, validator = lambda val: True):
 
     """
     Presents the user with a validated question, keeps asking if validation does not pass.
