@@ -7,19 +7,27 @@ but merely provides the workhorse for finding and manipulating colors.
 With the ``Style`` class, any color can be directly called or given to a with statement.
 """
 
-from __future__ import print_function
+from __future__ import print_function, absolute_import
 import sys
 import os
 import re
 from copy import copy
-from plumbum.colorlib.names import color_names, color_html
-from plumbum.colorlib.names import color_codes_simple, from_html
-from plumbum.colorlib.names import FindNearest, attributes_ansi
-from plumbum.lib import six
-from plumbum import local
-from abc import abstractmethod
+from .names import color_names, color_html
+from .names import color_codes_simple, from_html
+from .names import FindNearest, attributes_ansi
+from abc import abstractmethod, ABCMeta
 import platform
-ABC = six.ABC
+
+try:
+    from abc import ABC
+except ImportError:
+    from abc import ABCMeta # type: ignore
+    ABC = ABCMeta('ABC', (object,), {'__module__':__name__, '__slots__':('__weakref__')}) # type: ignore
+
+try:
+    from typing import IO, Dict, Union
+except ImportError:
+    pass
 
 __all__ = ['Color', 'Style', 'ANSIStyle', 'HTMLStyle', 'ColorNotFound', 'AttributeNotFound']
 
@@ -31,8 +39,8 @@ def get_color_repr():
     """Gets best colors for current system."""
     if not sys.stdout.isatty():
         return False
-    
-    term =local.env.get("TERM", "")
+
+    term =os.environ.get("TERM", "")
 
     # Some terminals set TERM=xterm for compatibility
     if term.endswith("256color") or term == "xterm":
@@ -106,7 +114,7 @@ class Color(ABC):
 
         """
 
-    __slots__ = ('fg', 'isreset', 'rgb', 'number', 'representation', 'exact', '__weakref__')
+    __slots__ = ('fg', 'isreset', 'rgb', 'number', 'representation', 'exact')
 
     def __init__(self, r_or_color=None, g=None, b=None, fg=True):
         """This works from color values, or tries to load non-simple ones."""
@@ -339,8 +347,8 @@ class Style(object):
     """The class of color to use. Never hardcode ``Color`` call when writing a Style
     method."""
 
-    attribute_names = None # should be a dict of valid names
-    _stdout = None
+    attribute_names = None # type: Union[Dict[str,str], Dict[str,int]]
+    _stdout = None # type: IO
     end = '\n'
     """The endline character. Override if needed in subclasses."""
 
