@@ -7,7 +7,6 @@ from tempfile import TemporaryFile
 from subprocess import PIPE, Popen
 from types import MethodType
 
-
 class RedirectionError(Exception):
     """Raised when an attempt is made to redirect an process' standard handle,
     which was already redirected to/from a file"""
@@ -23,7 +22,7 @@ def shquote(text):
     """Quotes the given text with shell escaping (assumes as syntax similar to ``sh``)"""
     if not text:
         return "''"
-    text = str(text)
+    text = six.str(text)
     if not text:
         return "''"
     for c in text:
@@ -33,8 +32,8 @@ def shquote(text):
         return text
     if "'" not in text:
         return "'" + text + "'"
-    res = "".join(('\\' + c if c in _funnychars else c) for c in text)
-    return '"' + res + '"'
+    res = six.str("").join((six.str('\\' + c) if c in _funnychars else c) for c in text)
+    return six.str('"') + res + six.str('"')
 
 def shquote_list(seq):
     return [shquote(item) for item in seq]
@@ -46,7 +45,7 @@ def shquote_list(seq):
 class BaseCommand(object):
     """Base of all command objects"""
 
-    __slots__ = ["cwd", "env", "encoding", "__weakref__"]
+    __slots__ = ("cwd", "env", "custom_encoding", "__weakref__")
 
     def __str__(self):
         return " ".join(self.formulate())
@@ -75,9 +74,14 @@ class BaseCommand(object):
         return StdinDataRedirection(self, data)
 
     def __getitem__(self, args):
-        """Creates a bound-command with the given arguments"""
+        """Creates a bound-command with the given arguments. Shortcut for
+        bound_command."""
         if not isinstance(args, (tuple, list)):
             args = [args, ]
+        return self.bound_command(*args)
+
+    def bound_command(self, *args):
+        """Creates a bound-command with the given arguments"""
         if not args:
             return self
         if isinstance(self, BoundCommand):
@@ -85,6 +89,7 @@ class BaseCommand(object):
         else:
             return BoundCommand(self, args)
 
+
     def __call__(self, *args, **kwargs):
         """A shortcut for `run(args)`, returning only the process' stdout"""
         return self.run(args, **kwargs)[1]
@@ -135,7 +140,7 @@ class BaseCommand(object):
         :returns: A ``Popen``-like object
         """
         raise NotImplementedError()
-        
+
     def nohup(self, command, cwd='.', stdout='nohup.out', stderr=None, append=True):
         """Runs a command detached."""
         return self.machine.daemonic_popen(self, cwd, stdout, stderr, append)
@@ -221,7 +226,7 @@ class BaseCommand(object):
 
 
 class BoundCommand(BaseCommand):
-    __slots__ = ["cmd", "args"]
+    __slots__ = ("cmd", "args")
     def __init__(self, cmd, args):
         self.cmd = cmd
         self.args = list(args)
@@ -240,7 +245,7 @@ class BoundCommand(BaseCommand):
         return self.cmd.popen(self.args + list(args), **kwargs)
 
 class BoundEnvCommand(BaseCommand):
-    __slots__ = ["cmd", "envvars"]
+    __slots__ = ("cmd", "envvars")
     def __init__(self, cmd, envvars):
         self.cmd = cmd
         self.envvars = envvars
@@ -258,7 +263,7 @@ class BoundEnvCommand(BaseCommand):
             return self.cmd.popen(args, **kwargs)
 
 class Pipeline(BaseCommand):
-    __slots__ = ["srccmd", "dstcmd"]
+    __slots__ = ("srccmd", "dstcmd")
     def __init__(self, srccmd, dstcmd):
         self.srccmd = srccmd
         self.dstcmd = dstcmd
@@ -276,6 +281,8 @@ class Pipeline(BaseCommand):
     def popen(self, args = (), **kwargs):
         src_kwargs = kwargs.copy()
         src_kwargs["stdout"] = PIPE
+        if "stdin" in kwargs:
+            src_kwargs["stdin"] = kwargs["stdin"]
 
         srcproc = self.srccmd.popen(args, **src_kwargs)
         kwargs["stdin"] = srcproc.stdout
@@ -284,7 +291,7 @@ class Pipeline(BaseCommand):
         srcproc.stdout.close()
         if srcproc.stderr is not None:
             dstproc.stderr = srcproc.stderr
-        if srcproc.stdin:
+        if srcproc.stdin and src_kwargs.get('stdin') != PIPE:
             srcproc.stdin.close()
         dstproc.srcproc = srcproc
 
@@ -296,7 +303,7 @@ class Pipeline(BaseCommand):
             rc_src = srcproc.wait(*args, **kwargs)
             dstproc.returncode = rc_dst or rc_src
             return dstproc.returncode
-        dstproc.wait = wait2
+        dstproc._proc.wait = wait2
 
         dstproc_verify = dstproc.verify
         def verify(proc, retcode, timeout, stdout, stderr):
@@ -305,18 +312,22 @@ class Pipeline(BaseCommand):
             try:
                 or_retcode = [0] + list(retcode)
             except TypeError:
-                or_retcode = [0, retcode]
+                if (retcode is None):
+                    or_retcode = None # no-retcode-verification acts "greedily"
+                else:
+                    or_retcode = [0, retcode]
             proc.srcproc.verify(or_retcode, timeout, stdout, stderr)
             dstproc_verify(retcode, timeout, stdout, stderr)
         dstproc.verify = MethodType(verify, dstproc)
 
+        dstproc.stdin = srcproc.stdin
         return dstproc
 
 class BaseRedirection(BaseCommand):
-    __slots__ = ["cmd", "file"]
-    SYM = None
-    KWARG = None
-    MODE = None
+    __slots__ = ("cmd", "file")
+    SYM = None # type: str
+    KWARG = None # type: str
+    MODE = None # type: str
 
     def __init__(self, cmd, file):
         self.cmd = cmd
@@ -350,38 +361,38 @@ class BaseRedirection(BaseCommand):
                 f.close()
 
 class StdinRedirection(BaseRedirection):
-    __slots__ = []
+    __slots__ = ()
     SYM = "<"
     KWARG = "stdin"
     MODE = "r"
 
 class StdoutRedirection(BaseRedirection):
-    __slots__ = []
+    __slots__ = ()
     SYM = ">"
     KWARG = "stdout"
     MODE = "w"
 
 class AppendingStdoutRedirection(BaseRedirection):
-    __slots__ = []
+    __slots__ = ()
     SYM = ">>"
     KWARG = "stdout"
     MODE = "a"
 
 class StderrRedirection(BaseRedirection):
-    __slots__ = []
+    __slots__ = ()
     SYM = "2>"
     KWARG = "stderr"
     MODE = "w"
 
-class ERROUT(int):
+class _ERROUT(int):
     def __repr__(self):
         return "ERROUT"
     def __str__(self):
         return "&1"
-ERROUT = ERROUT(subprocess.STDOUT)
+ERROUT = _ERROUT(subprocess.STDOUT)
 
 class StdinDataRedirection(BaseCommand):
-    __slots__ = ["cmd", "data"]
+    __slots__ = ("cmd", "data")
     CHUNK_SIZE = 16000
 
     def __init__(self, cmd, data):
@@ -413,25 +424,25 @@ class StdinDataRedirection(BaseCommand):
         #    f.close()
 
 class ConcreteCommand(BaseCommand):
-    QUOTE_LEVEL = None
-    __slots__ = ["executable", "encoding"]
+    QUOTE_LEVEL = None # type: int
+    __slots__ = ("executable", "custom_encoding")
     def __init__(self, executable, encoding):
         self.executable = executable
-        self.encoding = encoding
+        self.custom_encoding = encoding
         self.cwd = None
         self.env = None
-        
+
     def __str__(self):
         return str(self.executable)
-        
+
     def __repr__(self):
-        return "{0}({1})".format(type(self).__name__, self.executable)        
-    
+        return "{0}({1})".format(type(self).__name__, self.executable)
+
     def _get_encoding(self):
-        return self.encoding
+        return self.custom_encoding
 
     def formulate(self, level = 0, args = ()):
-        argv = [str(self.executable)]
+        argv = [six.str(self.executable)]
         for a in args:
             if a is None:
                 continue
@@ -441,18 +452,10 @@ class ConcreteCommand(BaseCommand):
                 else:
                     argv.extend(a.formulate(level + 1))
             elif isinstance(a, (list, tuple)):
-                argv.extend(shquote(b) if level >= self.QUOTE_LEVEL else str(b) for b in a)
+                argv.extend(shquote(b) if level >= self.QUOTE_LEVEL else six.str(b) for b in a)
             else:
-                argv.append(shquote(a) if level >= self.QUOTE_LEVEL else str(a))
-        # if self.encoding:
-        #    argv = [a.encode(self.encoding) for a in argv if isinstance(a, six.string_types)]
+                argv.append(shquote(a) if level >= self.QUOTE_LEVEL else six.str(a))
+        # if self.custom_encoding:
+        #    argv = [a.encode(self.custom_encoding) for a in argv if isinstance(a, six.string_types)]
         return argv
 
-        
-        
-
-
-
-
-
-
