@@ -28,7 +28,11 @@ class six(object):
     A light-weight version of six (which works on IronPython)
     """
     PY3 = sys.version_info[0] >= 3
-    ABC = ABCMeta('ABC', (object,), {'__module__':__name__, '__slots__':()})
+    try:
+        from abc import ABC
+    except ImportError:
+        from abc import ABCMeta # type: ignore
+        ABC = ABCMeta('ABC', (object,), {'__module__':__name__, '__slots__':()}) # type: ignore
 
     # Be sure to use named-tuple access, so that usage is not affected
     try:
@@ -71,12 +75,14 @@ class six(object):
         def get_method_function(m):
             return m.im_func
 
+    str = unicode_type
+
 # Try/except fails because io has the wrong StringIO in Python2
 # You'll get str/unicode errors
 if six.PY3:
     from io import StringIO
 else:
-    from StringIO import StringIO
+    from StringIO import StringIO # type: ignore
 
 
 @contextmanager
