@@ -19,8 +19,8 @@ from plumbum.machines.base import BaseMachine
 from plumbum.machines.base import PopenAddons
 from plumbum.machines.env import BaseEnv
 
-if sys.version_info >= (3, 2):
-    # python 3.2 has the new-and-improved subprocess module
+if sys.version_info[0] >= 3:
+    # python 3 has the new-and-improved subprocess module
     from subprocess import Popen, PIPE
     has_new_subprocess = True
 else:
@@ -32,11 +32,20 @@ else:
         from subprocess import Popen, PIPE
         has_new_subprocess = False
 
-class IterablePopen(Popen, PopenAddons):
+class PlumbumLocalPopen(PopenAddons):
     iter_lines = iter_lines
+
+    def __init__(self, *args, **kwargs):
+        self._proc = Popen(*args, **kwargs)
+
     def __iter__(self):
         return self.iter_lines()
 
+    def __getattr__(self, name):
+        return getattr(self._proc, name)
+
+if IS_WIN32:
+    from plumbum.machines._windows import get_pe_subsystem, IMAGE_SUBSYSTEM_WINDOWS_CUI
 
 logger = logging.getLogger("plumbum.local")
 
@@ -46,7 +55,7 @@ logger = logging.getLogger("plumbum.local")
 #===================================================================================================
 class LocalEnv(BaseEnv):
     """The local machine's environment; exposes a dict-like interface"""
-    __slots__ = []
+    __slots__ = ()
     CASE_SENSITIVE = not IS_WIN32
 
     def __init__(self):
@@ -90,7 +99,7 @@ class LocalEnv(BaseEnv):
 # Local Commands
 #===================================================================================================
 class LocalCommand(ConcreteCommand):
-    __slots__ = []
+    __slots__ = ()
     QUOTE_LEVEL = 2
 
     def __init__(self, executable, encoding = "auto"):
@@ -188,6 +197,14 @@ class LocalMachine(BaseMachine):
             parts2.append(self.env.expanduser(str(p)))
         return LocalPath(os.path.join(*parts2))
 
+    def __contains__(self, cmd):
+        try:
+            self[cmd]
+        except CommandNotFound:
+            return False
+        else:
+            return True
+
     def __getitem__(self, cmd):
         """Returns a `Command` object representing the given program. ``cmd`` can be a string or
         a :class:`LocalPath <plumbum.path.local.LocalPath>`; if it is a path, a command
@@ -223,7 +240,6 @@ class LocalMachine(BaseMachine):
                 kwargs["preexec_fn"] = preexec_fn
 
         if IS_WIN32 and "startupinfo" not in kwargs and stdin not in (sys.stdin, None):
-            from plumbum.machines._windows import get_pe_subsystem, IMAGE_SUBSYSTEM_WINDOWS_CUI
             subsystem = get_pe_subsystem(str(executable))
 
             if subsystem == IMAGE_SUBSYSTEM_WINDOWS_CUI:
@@ -255,7 +271,7 @@ class LocalMachine(BaseMachine):
             argv, executable = self._as_user_stack[-1](argv)
 
         logger.debug("Running %r", argv)
-        proc = IterablePopen(argv, executable = str(executable), stdin = stdin, stdout = stdout,
+        proc = PlumbumLocalPopen(argv, executable = str(executable), stdin = stdin, stdout = stdout,
             stderr = stderr, cwd = str(cwd), env = env, **kwargs)  # bufsize = 4096
         proc._start_time = time.time()
         proc.custom_encoding = self.custom_encoding
