@@ -69,6 +69,17 @@ class Path(str, six.ABC):
         return bool(str(self))
     __bool__ = __nonzero__
 
+    def __fpath__(self):
+        """Added for Python 3.6 support"""
+        return str(self)
+
+    def __contains__(self, item):
+        """Paths should support checking to see if an file or folder is in them."""
+        try:
+            return (self / item.name).exists()
+        except AttributeError:
+            return (self / item).exists()
+
     @abstractmethod
     def _form(self, *parts):
         pass
@@ -282,7 +293,7 @@ class Path(str, six.ABC):
     def unlink(self):
         """Deletes a symbolic link"""
 
-    def split(self):
+    def split(self, *dummy_args, **dummy_kargs):
         """Splits the path on directory separators, yielding a list of directories, e.g,
         ``"/var/log/messages"`` will yield ``['var', 'log', 'messages']``.
         """
@@ -330,6 +341,24 @@ class Path(str, six.ABC):
                 results.extend(fn(single_pattern))
             return sorted(list(set(results)))
 
+    def resolve(strict=False):
+        """Added to allow pathlib like syntax. Does nothing since
+        Plumbum paths are always absolute. Does not (currently) resolve
+        symlinks."""
+        # TODO: Resolve symlinks here
+        return self
+
+    @property
+    def parents(self):
+        """Pathlib like sequence of ancestors"""
+        join = lambda x,y: self.__class__(x) / y
+        as_list = (reduce(join,self.parts[:i],self.parts[0]) for i in range(len(self.parts)-1,0,-1))
+        return tuple(as_list)
+
+    @property
+    def parent(self):
+        """Pathlib like parent of the path."""
+        return self.parents[0]
 
 
 class RelativePath(object):
